@@ -54,17 +54,17 @@ AdaBagModel <- function(
     label = "Bagging with Classification Trees",
     packages = "adabag",
     response_types = "factor",
-    predictor_encoding = "terms",
+    predictor_encoding = "model.frame",
     params = params,
     gridinfo = new_gridinfo(
       param = c("mfinal", "maxdepth"),
       values = c(
         function(n, ...) round(seq_range(0, 25, c(1, 200), n + 1)),
-        function(n, ...) 1:min(n, 30)
+        function(n, ...) seq_len(min(n, 30))
       )
     ),
     fit = function(formula, data, weights, ...) {
-      assert_equal_weights(weights)
+      throw(check_equal_weights(weights))
       adabag::bagging(formula, data = as.data.frame(data), ...)
     },
     predict = function(object, newdata, ...) {
