@@ -55,12 +55,12 @@ CoxModel <- function(ties = c("efron", "breslow", "exact"), ...) {
       survival::coxph(formula, data = as.data.frame(data), weights = weights,
                       ...)
     },
-    predict = function(object, newdata, times, ...) {
+    predict = function(object, newdata, ...) {
       y <- object$y
       newdata <- as.data.frame(newdata)
       lp <- predict(object, type = "lp")
       new_lp <- predict(object, newdata = newdata, type = "lp")
-      predict(y, lp, times, new_lp, ...)
+      predict(y, lp, new_lp, ...)
     },
     varimp = function(object, base = exp(1), ...) {
       varimp_pval(object, base = base)
