@@ -67,7 +67,7 @@ GAMBoostModel <- function(
     packages = "mboost",
     response_types = c("binary", "BinomialVariate", "NegBinomialVariate",
                        "numeric", "PoissonVariate", "Surv"),
-    predictor_encoding = "terms",
+    predictor_encoding = "model.frame",
     params = params,
     gridinfo = new_gridinfo(
       param = "mstop",
@@ -97,12 +97,12 @@ GAMBoostModel <- function(
       mboost::gamboost(formula, data = as.data.frame(data), na.action = na.pass,
                        weights = weights, family = family, ...)
     },
-    predict = function(object, newdata, times, ...) {
+    predict = function(object, newdata, ...) {
       newdata <- as.data.frame(newdata)
       if (object$family@name == "Cox Partial Likelihood") {
         lp <- drop(predict(object, type = "link"))
         new_lp <- drop(predict(object, newdata = newdata, type = "link"))
-        predict(object$response, lp, times, new_lp, ...)
+        predict(object$response, lp, new_lp, ...)
       } else {
         predict(object, newdata = newdata, type = "response")
       }
