@@ -57,7 +57,7 @@ GLMBoostModel <- function(
     packages = "mboost",
     response_types = c("binary", "BinomialVariate", "NegBinomialVariate",
                        "numeric", "PoissonVariate", "Surv"),
-    predictor_encoding = "terms",
+    predictor_encoding = "model.frame",
     params = params,
     gridinfo = new_gridinfo(
       param = "mstop",
@@ -84,12 +84,12 @@ GLMBoostModel <- function(
                matrix = mboost::glmboost(x, y, weights = weights,
                                          family = family, ...))
     },
-    predict = function(object, newdata, times, ...) {
+    predict = function(object, newdata, ...) {
       newdata <- as.data.frame(newdata)
       if (object$family@name == "Cox Partial Likelihood") {
         lp <- drop(predict(object, type = "link"))
         new_lp <- drop(predict(object, newdata = newdata, type = "link"))
-        predict(object$response, lp, times, new_lp, ...)
+        predict(object$response, lp, new_lp, ...)
       } else {
         predict(object, newdata = newdata, type = "response")
       }
