@@ -58,7 +58,7 @@ LARSModel <- function(
       )
     ),
     fit = function(formula, data, weights, step = NULL, ...) {
-      assert_equal_weights(weights)
+      throw(check_equal_weights(weights))
       x <- model.matrix(data, intercept = FALSE)
       y <- response(data)
       if (is.null(step)) {
