@@ -67,11 +67,11 @@ MDAModel <- function(
     gridinfo = new_gridinfo(
       param = "subclasses",
       values = c(
-        function(n, ...) 1:min(n, 10) + 1
+        function(n, ...) seq(2, length = min(n, 10))
       )
     ),
     fit = function(formula, data, weights, ...) {
-      assert_equal_weights(weights)
+      throw(check_equal_weights(weights))
       mda::mda(formula, data = as.data.frame(data), ...)
     },
     predict = function(object, newdata, prior = object$prior, ...) {
