@@ -31,10 +31,10 @@ NaiveBayesModel <- function(laplace = 0) {
     label = "Naive Bayes Classifier",
     packages = "e1071",
     response_types = "factor",
-    predictor_encoding = "terms",
+    predictor_encoding = "model.frame",
     params = params(environment()),
     fit = function(formula, data, weights, ...) {
-      assert_equal_weights(weights)
+      throw(check_equal_weights(weights))
       eval_fit(data,
                formula = e1071::naiveBayes(formula, data = as.data.frame(data),
                                            ...),
