@@ -10,29 +10,31 @@ ModelRecipe.ModelRecipe <- function(object, ...) {
 
 ModelRecipe.recipe <- function(object, ...) {
   if (any(map_logi(function(step) isTRUE(step$trained), object$steps))) {
-    stop("recipe must be untrained")
+    throw(Error("recipe must be untrained"))
   }
 
-  case_name_var <- "(names)"
-  case_name_fo <- ~ -`(names)`
+  cases_name <- "(names)"
+  cases_fo <- ~ -`(names)`
 
-  if (case_name_var %in% summary(object)$variable) {
-    stop("conflict with existing recipe variable: ", case_name_var)
+  reserved <- intersect(c(cases_name, "(strata)"), summary(object)$variable)
+  if (length(reserved)) {
+    msg <- label_items("supplied recipe contains reserved variable", reserved)
+    throw(Error(msg))
   }
-  case_name_info <- data.frame(
-    variable = case_name_var,
+  cases_info <- data.frame(
+    variable = cases_name,
     type = "nominal",
     role = "case_name",
     source = "original"
   )
-  object$var_info <- rbind(object$var_info, case_name_info)
-  object$term_info <- rbind(object$term_info, case_name_info)
-  object$template[[case_name_var]] <- rownames(object$template)
+  object$var_info <- rbind(object$var_info, cases_info)
+  object$term_info <- rbind(object$term_info, cases_info)
+  object$template[[cases_name]] <- rownames(object$template)
 
-  for (i in seq(object$steps)) {
+  for (i in seq_along(object$steps)) {
     step_terms <- object$steps[[i]]$terms
-    environment(case_name_fo) <- environment(step_terms[[1]])
-    new_term <- rlang::as_quosure(case_name_fo)
+    environment(cases_fo) <- environment(step_terms[[1]])
+    new_term <- rlang::as_quosure(cases_fo)
     object$steps[[i]]$terms <- c(step_terms, new_term)
   }
 
@@ -46,12 +48,12 @@ bake.ModelRecipe <- function(object, new_data, ...) {
 
 
 bake.SelectedInput <- function(object, ...) {
-  stop("cannot create a design matrix from a ", class(object))
+  throw(Error("cannot create a design matrix from a ", class(object)))
 }
 
 
 bake.TunedInput <- function(object, ...) {
-  stop("cannot create a design matrix from a ", class(object))
+  throw(Error("cannot create a design matrix from a ", class(object)))
 }
 
 
@@ -75,30 +77,29 @@ prep.ModelFrame <- function(x, ...) x
 
 prep.ModelRecipe <- function(x, ...) {
   if (!recipes::fully_trained(x)) {
-    case_name_var <- "(names)"
     template <- x$template
     x <- new(class(x), prep(as(x, "recipe"), retain = FALSE))
     x$template <- template
-    x$orig_lvls[[case_name_var]] <- list(values = NA, ordered = NA)
-    x$levels[[case_name_var]] <- x$orig_lvls[[case_name_var]]
+    x$orig_lvls[["(names)"]] <- list(values = NA, ordered = NA)
+    x$levels[["(names)"]] <- x$orig_lvls[["(names)"]]
   }
   x
 }
 
 
 prep.SelectedInput <- function(x, ...) {
-  stop("cannot train a ", class(x))
+  throw(Error("cannot train a ", class(x)))
 }
 
 
 prep.TunedInput <- function(x, ...) {
-  stop("cannot train a ", class(x))
+  throw(Error("cannot train a ", class(x)))
 }
 
 
 prep_recipe_data <- function(x) {
-  case_name_var <- "(names)"
-  if (is.null(x[[case_name_var]])) x[[case_name_var]] <- rownames(x)
+  if (is.null(x[["(names)"]])) x[["(names)"]] <- rownames(x)
+  x[["(strata)"]] <- NULL
   x
 }
 
@@ -112,7 +113,7 @@ recipe.ModelRecipe <- function(x, data, ...) {
 
 update.recipe <- function(object, ...) {
   args <- list(...)
-  for (i in seq(object$steps)) {
+  for (i in seq_along(object$steps)) {
     step <- object$steps[[i]]
     params <- args[[step$id]]
     if (!is.null(params)) {
