@@ -24,8 +24,10 @@ setOldClass("Surv")
 
 setClass("DiscreteVariate",
   contains = "numeric",
-  slots = c(min = "numeric",
-            max = "numeric")
+  slots = c(
+    min = "numeric",
+    max = "numeric"
+  )
 )
 
 
@@ -41,7 +43,10 @@ setClass("PoissonVariate",
 
 setClass("SurvMatrix",
   contains = "matrix",
-  slots = c(times = "numeric")
+  slots = c(
+    times = "numeric",
+    distr = "character"
+  )
 )
 
 
@@ -55,6 +60,12 @@ setClass("SurvProbs",
 )
 
 
+setClass("SurvMeans",
+  contains = "numeric",
+  slots = c(distr = "character")
+)
+
+
 #################### Tuning Grids ####################
 
 
@@ -65,8 +76,10 @@ setOldClass(c("grid_regular", "param_grid"))
 
 
 setClass("Grid",
-  slots = c(size = "integer",
-            random = "ANY")
+  slots = c(
+    size = "integer",
+    random = "ANY"
+  )
 )
 
 
@@ -84,18 +97,20 @@ RecipeGrid <- setClass("RecipeGrid",
 
 
 setClass("MLModel",
-  slots = c(name = "character",
-            label = "character",
-            packages = "character",
-            response_types = "character",
-            predictor_encoding = "character",
-            params = "list",
-            gridinfo = "tbl_df",
-            fit = "function",
-            predict = "function",
-            varimp = "function",
-            x = "ANY",
-            train_steps = "ListOf")
+  slots = c(
+    name = "character",
+    label = "character",
+    packages = "character",
+    response_types = "character",
+    predictor_encoding = "character",
+    params = "list",
+    gridinfo = "tbl_df",
+    fit = "function",
+    predict = "function",
+    varimp = "function",
+    x = "ANY",
+    train_steps = "ListOf"
+  )
 )
 
 
@@ -176,8 +191,10 @@ setClass("ModeledRecipe",
 
 setClass("SelectedInput",
   contains = "VIRTUAL",
-  slots = c(inputs = "ListOf",
-            params = "list")
+  slots = c(
+    inputs = "ListOf",
+    params = "list"
+  )
 )
 
 
@@ -193,8 +210,10 @@ setClass("SelectedModelRecipe",
 
 setClass("TunedInput",
   contains = "VIRTUAL",
-  slots = c(grid = "ANY",
-            params = "list")
+  slots = c(
+    grid = "ANY",
+    params = "list"
+  )
 )
 
 
@@ -234,16 +253,22 @@ setClass("CForestModelFit", contains = c("MLModelFit", "RandomForest"))
 
 
 setClass("MLControl",
-  slots = c(times = "ANY",
-            dist = "ANY",
-            method = "ANY",
-            seed = "numeric")
+  slots = c(
+    strata_breaks = "integer",
+    strata_nunique = "integer",
+    strata_prop = "numeric",
+    strata_size = "integer",
+    times = "ANY",
+    distr = "ANY",
+    method = "ANY",
+    seed = "numeric"
+  )
 )
 
 
 setClass("MLBootstrapControl",
   contains = "MLControl",
-  slots = c(samples = "numeric")
+  slots = c(samples = "integer")
 )
 
 
@@ -259,8 +284,10 @@ setClass("MLBootOptimismControl",
 
 setClass("MLCrossValidationControl",
   contains = "MLControl",
-  slots = c(folds = "numeric",
-            repeats = "numeric")
+  slots = c(
+    folds = "integer",
+    repeats = "integer"
+  )
 )
 
 
@@ -276,7 +303,7 @@ setClass("MLCVOptimismControl",
 
 setClass("MLOOBControl",
   contains = "MLControl",
-  slots = c(samples = "numeric")
+  slots = c(samples = "integer")
 )
 
 
@@ -327,18 +354,22 @@ setClass("OrderedBinaryConfusionMatrix",
 
 ConfusionSummary <- setClass("ConfusionSummary",
   contains = "matrix",
-  slots = c(total = "numeric",
-            accuracy = "numeric",
-            majority = "numeric",
-            kappa2 = "numeric")
+  slots = c(
+    total = "numeric",
+    accuracy = "numeric",
+    majority = "numeric",
+    kappa2 = "numeric"
+  )
 )
 
 
 setClass("MLMetric",
   contains = "function",
-  slots = c(name = "character",
-            label = "character",
-            maximize = "logical")
+  slots = c(
+    name = "character",
+    label = "character",
+    maximize = "logical"
+  )
 )
 
 
@@ -372,22 +403,28 @@ setClass("LiftCurve",
 
 setClass("Resamples",
   contains = "data.frame",
-  slots = c(control = "MLControl",
-            strata = "character")
+  slots = c(
+    control = "MLControl",
+    strata = "character"
+  )
 )
 
 
 TrainStep <- setClass("TrainStep",
-  slots = c(grid = "tbl_df",
-            performance = "Performance",
-            selected = "numeric",
-            values = "numeric",
-            metric = "MLMetric")
+  slots = c(
+    grid = "tbl_df",
+    performance = "Performance",
+    selected = "numeric",
+    values = "numeric",
+    metric = "MLMetric"
+  )
 )
 
 
 setClass("VarImp",
   contains = "data.frame",
-  slots = c(shift = "numeric",
-            scale = "numeric")
+  slots = c(
+    shift = "numeric",
+    scale = "numeric"
+  )
 )
