@@ -69,7 +69,7 @@ setMetric_numeric("msle",
 
 #' @rdname metrics
 #'
-r2 <- function(observed, predicted = NULL, dist = NULL, ...) {
+r2 <- function(observed, predicted = NULL, distr = NULL, ...) {
   call_metric_method("r2", environment())
 }
 
@@ -96,17 +96,13 @@ setMetricMethod_Resamples("r2")
 
 
 setMetricMethod("r2", c("Surv", "numeric"),
-  function(observed, predicted, dist, ...) {
-    dist <- if (is.null(dist)) {
-      settings("dist.Surv")
-    } else {
-      match.arg(dist, c("empirical", names(survreg.distributions)))
-    }
-    nparams <- if (dist %in% c("exponential", "rayleigh")) 1 else 2
-    observed_mean <- if (dist == "empirical") {
+  function(observed, predicted, distr, ...) {
+    distr <- get_surv_distr(distr, observed, predicted)
+    nparams <- if (distr %in% c("exponential", "rayleigh")) 1 else 2
+    observed_mean <- if (distr == "empirical") {
       rep(mean(survfit(observed ~ 1, se.fit = FALSE)), length(observed))
-    } else if (length(surv_times(observed)) >= nparams) {
-      predict(survreg(observed ~ 1, dist = dist))
+    } else if (length(event_time(observed)) >= nparams) {
+      predict(survreg(observed ~ 1, dist = distr))
     } else {
       rep(NA_real_, length(observed))
     }
