@@ -15,7 +15,7 @@ NULL
 #' @rdname print-methods
 #'
 print.BinomialVariate <- function(
-  x, n = MachineShop::settings("max.print"), ...
+  x, n = MachineShop::settings("print_max"), ...
 ) {
   print_title(x)
   print_items(as(x, "matrix"), n = n)
@@ -25,7 +25,7 @@ print.BinomialVariate <- function(
 
 #' @rdname print-methods
 #'
-print.Calibration <- function(x, n = MachineShop::settings("max.print"), ...) {
+print.Calibration <- function(x, n = MachineShop::settings("print_max"), ...) {
   print_title(x)
   print_items(as(x, "data.frame"), n = n)
   invisible(x)
@@ -41,7 +41,7 @@ setMethod("show", "Calibration",
 
 
 print.ConfusionList <- function(
-  x, n = MachineShop::settings("max.print"), ...
+  x, n = MachineShop::settings("print_max"), ...
 ) {
   print_title(x)
   cat("\n")
@@ -50,7 +50,7 @@ print.ConfusionList <- function(
 
 
 print.ConfusionMatrix <- function(
-  x, n = MachineShop::settings("max.print"), ...
+  x, n = MachineShop::settings("print_max"), ...
 ) {
   print_title(x)
   print(as(x, "table"))
@@ -67,7 +67,7 @@ setMethod("show", "ConfusionMatrix",
 
 
 print.ConfusionSummary <- function(
-  x, n = MachineShop::settings("max.print"), ...
+  x, n = MachineShop::settings("print_max"), ...
 ) {
   total <- x@total
   acc <- x@accuracy
@@ -89,11 +89,13 @@ setMethod("show", "ConfusionSummary",
 )
 
 
+#' @rdname print-methods
+#'
 print.DiscreteVariate <- function(
-  x, n = MachineShop::settings("max.print"), ...
+  x, n = MachineShop::settings("print_max"), ...
 ) {
   print_title(x)
-  print(as(x, "numeric"))
+  print_items(as(x, "numeric"), n = n)
   cat("Range: ", x@min, ", ", x@max, "\n", sep = "")
   invisible(x)
 }
@@ -107,10 +109,10 @@ setMethod("show", "DiscreteVariate",
 )
 
 
-print.Grid <- function(x, n = MachineShop::settings("max.print"), ...) {
+print.Grid <- function(x, n = MachineShop::settings("print_max"), ...) {
   print_title(x)
   cat("\n",
-      label_items("Size", x@size, add_names = TRUE), "\n",
+      label_items("Grid size", x@size, add_names = TRUE), "\n",
       "Random sample: ", x@random, "\n",
       sep = ""
   )
@@ -128,7 +130,7 @@ setMethod("show", "Grid",
 
 #' @rdname print-methods
 #'
-print.ListOf <- function(x, n = MachineShop::settings("max.print"), ...) {
+print.ListOf <- function(x, n = MachineShop::settings("print_max"), ...) {
   print_items(as(x, "listof"), n = n)
   invisible(x)
 }
@@ -142,7 +144,7 @@ setMethod("show", "ListOf",
 )
 
 
-print.MLControl <- function(x, n = MachineShop::settings("max.print"), ...) {
+print.MLControl <- function(x, n = MachineShop::settings("print_max"), ...) {
   show(x)
   invisible(x)
 }
@@ -150,11 +152,18 @@ print.MLControl <- function(x, n = MachineShop::settings("max.print"), ...) {
 
 setMethod("show", "MLControl",
   function(object) {
-    labels <- c("times" = "Survival times", "method" = "Method",
-                "dist" = "Distribution")
-    for (name in names(labels)) {
+    cat("Stratification parameters\n",
+        "  Breaks: ", object@strata_breaks, "\n",
+        "  Unique numeric threshold: ", object@strata_nunique, "\n",
+        "  Minimum proportion: ", object@strata_prop, "\n",
+        "  Minimum size: ", object@strata_size, "\n",
+        sep = "")
+    opts <- c("times" = "Survival times",
+              "method" = "Method",
+              "distr" = "Distribution")
+    for (name in names(opts)) {
       x <- slot(object, name)
-      if (length(x)) cat(labels[name], ": ", toString(x), "\n", sep = "")
+      if (length(x)) cat(opts[name], ": ", toString(x), "\n", sep = "")
     }
     cat("Seed:", object@seed, "\n")
     invisible()
@@ -275,7 +284,7 @@ setMethod("show", "MLTrainControl",
 )
 
 
-print.MLMetric <- function(x, n = MachineShop::settings("max.print"), ...) {
+print.MLMetric <- function(x, n = MachineShop::settings("print_max"), ...) {
   print_title(x)
   cat("\n",
       "Metric name: ", x@name, "\n",
@@ -301,7 +310,7 @@ setMethod("show", "MLMetric",
 
 #' @rdname print-methods
 #'
-print.MLModel <- function(x, n = MachineShop::settings("max.print"), ...) {
+print.MLModel <- function(x, n = MachineShop::settings("print_max"), ...) {
   print_title(x)
   trained <- is_trained(x)
   print_modelinfo(x, trained = trained)
@@ -338,7 +347,7 @@ setMethod("show", "MLModelFit",
 
 
 print.MLModelFunction <- function(
-  x, n = MachineShop::settings("max.print"), ...
+  x, n = MachineShop::settings("print_max"), ...
 ) {
   print_title(x)
   print_modelinfo(x)
@@ -358,7 +367,7 @@ setMethod("show", "MLModelFunction",
 
 #' @rdname print-methods
 #'
-print.ModelFrame <- function(x, n = MachineShop::settings("max.print"), ...) {
+print.ModelFrame <- function(x, n = MachineShop::settings("print_max"), ...) {
   print_title(x)
   print_items(as(x, "data.frame"), n = n)
   invisible(x)
@@ -373,7 +382,7 @@ setMethod("show", "ModelFrame",
 )
 
 
-print.ModelRecipe <- function(x, n = MachineShop::settings("max.print"), ...) {
+print.ModelRecipe <- function(x, n = MachineShop::settings("print_max"), ...) {
   print_title(x)
   cat("\n")
   NextMethod()
@@ -389,14 +398,14 @@ setMethod("show", "ModelRecipe",
 )
 
 
-print.ModelTerms <- function(x, n = MachineShop::settings("max.print"), ...) {
+print.ModelTerms <- function(x, n = MachineShop::settings("print_max"), ...) {
   print(formula(x))
 }
 
 
 #' @rdname print-methods
 #'
-print.ModeledInput <- function(x, n = MachineShop::settings("max.print"), ...) {
+print.ModeledInput <- function(x, n = MachineShop::settings("print_max"), ...) {
   NextMethod()
   cat("\n")
   print(x@model, n = n)
@@ -404,7 +413,7 @@ print.ModeledInput <- function(x, n = MachineShop::settings("max.print"), ...) {
 }
 
 
-print.ModeledTerms <- function(x, n = MachineShop::settings("max.print"), ...) {
+print.ModeledTerms <- function(x, n = MachineShop::settings("print_max"), ...) {
   print(formula(x))
   cat("\n")
   print(x@model, n)
@@ -413,15 +422,11 @@ print.ModeledTerms <- function(x, n = MachineShop::settings("max.print"), ...) {
 
 
 print.ParameterGrid <- function(
-  x, n = MachineShop::settings("max.print"), ...
+  x, n = MachineShop::settings("print_max"), ...
 ) {
-  print_title(x)
+  NextMethod()
+  cat("\n")
   print(as(x, "parameters"))
-  if (x@random) {
-    cat("Random sample:", x@random, "\n")
-  } else {
-    cat(label_items("Size", x@size, add_names = TRUE), "\n")
-  }
   invisible(x)
 }
 
@@ -436,7 +441,7 @@ setMethod("show", "ParameterGrid",
 
 #' @rdname print-methods
 #'
-print.Performance <- function(x, n = MachineShop::settings("max.print"), ...) {
+print.Performance <- function(x, n = MachineShop::settings("print_max"), ...) {
   print_title(x)
   dn <- dimnames(x)
   cat("\nMetrics:", toString(dn[[2]]), "\n")
@@ -450,7 +455,7 @@ print.Performance <- function(x, n = MachineShop::settings("max.print"), ...) {
 #' @rdname print-methods
 #'
 print.PerformanceCurve <- function(
-  x, n = MachineShop::settings("max.print"), ...
+  x, n = MachineShop::settings("print_max"), ...
 ) {
   print_title(x)
   cat("\n",
@@ -472,7 +477,7 @@ setMethod("show", "PerformanceCurve",
 
 
 print.PerformanceDiffTest <- function(
-  x, n = MachineShop::settings("max.print"), ...
+  x, n = MachineShop::settings("print_max"), ...
 ) {
   print_title(x)
   cat("\n",
@@ -487,7 +492,7 @@ print.PerformanceDiffTest <- function(
 
 #' @rdname print-methods
 #'
-print.RecipeGrid <- function(x, n = MachineShop::settings("max.print"), ...) {
+print.RecipeGrid <- function(x, n = MachineShop::settings("print_max"), ...) {
   print_title(x)
   print_items(as(x, "tbl_df"), n = n)
   invisible(x)
@@ -504,7 +509,7 @@ setMethod("show", "RecipeGrid",
 
 #' @rdname print-methods
 #'
-print.Resamples <- function(x, n = MachineShop::settings("max.print"), ...) {
+print.Resamples <- function(x, n = MachineShop::settings("print_max"), ...) {
   print_title(x)
   print_items(levels(x$Model), n = n, prefix = "\nModels: ", exdent = 2)
   if (isTRUE(nzchar(x@strata))) {
@@ -527,7 +532,7 @@ setMethod("show", "Resamples",
 #' @rdname print-methods
 #'
 print.SelectedInput <- function(
-  x, n = MachineShop::settings("max.print"), ...
+  x, n = MachineShop::settings("print_max"), ...
 ) {
   NextMethod()
   cat("\nModel inputs:\n\n")
@@ -538,7 +543,7 @@ print.SelectedInput <- function(
 
 
 print.SelectedModel <- function(
-  x, n = MachineShop::settings("max.print"), ...
+  x, n = MachineShop::settings("print_max"), ...
 ) {
   print_title(x)
   trained <- is_trained(x)
@@ -554,7 +559,7 @@ print.SelectedModel <- function(
 }
 
 
-print.StackedModel <- function(x, n = MachineShop::settings("max.print"), ...) {
+print.StackedModel <- function(x, n = MachineShop::settings("print_max"), ...) {
   print_title(x)
   trained <- is_trained(x)
   print_modelinfo(x, trained = trained)
@@ -571,7 +576,7 @@ print.StackedModel <- function(x, n = MachineShop::settings("max.print"), ...) {
 }
 
 
-print.SuperModel <- function(x, n = MachineShop::settings("max.print"), ...) {
+print.SuperModel <- function(x, n = MachineShop::settings("print_max"), ...) {
   print_title(x)
   trained <- is_trained(x)
   print_modelinfo(x, trained = trained)
@@ -598,11 +603,12 @@ format.SurvMatrix <- function(x, ...) {
 
 #' @rdname print-methods
 #'
-print.SurvMatrix <- function(x, n = MachineShop::settings("max.print"), ...) {
+print.SurvMatrix <- function(x, n = MachineShop::settings("print_max"), ...) {
   print_title(x)
   print_items(as(x, "matrix"), n = n)
   cat("Times:\n")
   print(x@times)
+  cat("Distribution:", x@distr, "\n")
   invisible(x)
 }
 
@@ -615,7 +621,25 @@ setMethod("show", "SurvMatrix",
 )
 
 
-print.TabularArray <- function(x, n = MachineShop::settings("max.print"), ...) {
+#' @rdname print-methods
+#'
+print.SurvMeans <- function(x, n = MachineShop::settings("print_max"), ...) {
+  print_title(x)
+  print_items(as(x, "numeric"), n = n)
+  cat("Distribution:", x@distr, "\n")
+  invisible(x)
+}
+
+
+setMethod("show", "SurvMeans",
+  function(object) {
+    print(object)
+    invisible()
+  }
+)
+
+
+print.TabularArray <- function(x, n = MachineShop::settings("print_max"), ...) {
   print(as(x, "array"))
   invisible(x)
 }
@@ -631,7 +655,7 @@ setMethod("show", "TabularArray",
 
 #' @rdname print-methods
 #'
-print.TrainStep <- function(x, n = MachineShop::settings("max.print"), ...) {
+print.TrainStep <- function(x, n = MachineShop::settings("print_max"), ...) {
   print_title(x)
   if (length(x@grid)) {
     cat("\nGrid (selected = ", x@selected, "):\n", sep = "")
@@ -658,7 +682,7 @@ setMethod("show", "TrainStep",
 
 #' @rdname print-methods
 #'
-print.TunedInput <- function(x, n = MachineShop::settings("max.print"), ...) {
+print.TunedInput <- function(x, n = MachineShop::settings("print_max"), ...) {
   NextMethod()
   cat("\n")
   print_items(x@grid, n = n)
@@ -668,7 +692,7 @@ print.TunedInput <- function(x, n = MachineShop::settings("max.print"), ...) {
 }
 
 
-print.TunedModel <- function(x, n = MachineShop::settings("max.print"), ...) {
+print.TunedModel <- function(x, n = MachineShop::settings("print_max"), ...) {
   print_title(x)
   trained <- is_trained(x)
   print_modelinfo(x, trained = trained)
@@ -690,7 +714,7 @@ print.TunedModel <- function(x, n = MachineShop::settings("max.print"), ...) {
 
 #' @rdname print-methods
 #'
-print.VarImp <- function(x, n = MachineShop::settings("max.print"), ...) {
+print.VarImp <- function(x, n = MachineShop::settings("print_max"), ...) {
   print_title(x)
   print_items(as(x, "data.frame"), n = n)
   invisible(x)
@@ -752,9 +776,9 @@ print_items.list <- function(x, n = Inf, n_extra = 10 * n, ...) {
 
 
 print_items.listof <- function(x, n = Inf, n_extra = 10 * n, ...) {
-  inds <- head(seq(x), n)
+  inds <- head(seq_along(x), n)
   x_names <- names(x)
-  if (is.null(x_names)) x_names <- paste("Component", seq(x))
+  if (is.null(x_names)) x_names <- paste("Component", seq_along(x))
   vsep <- strrep("-", 0.75 * getOption("width"))
   for (i in inds) {
     cat(x_names[i], ":\n")
@@ -784,8 +808,8 @@ print_items.matrix <- function(x, n = Inf, n_extra = 10 * n, ...) {
   diff_cols <- ncol(x) - length(col_inds)
   cols <- tail(colnames(x), diff_cols)
   if (diff_rows) {
-    str <- paste("... with", format_len(diff_rows), "more row",
-                 if (diff_rows > 1) "\bs")
+    str <- paste0("... with ", format_len(diff_rows), " more row",
+                  if (diff_rows > 1) "s")
     if (diff_cols) {
       str <- paste(str, "and", format_len(diff_cols),
                    label_items("column", cols, n_extra))
@@ -798,6 +822,18 @@ print_items.matrix <- function(x, n = Inf, n_extra = 10 * n, ...) {
 }
 
 
+print_items.numeric <- function(x, n = Inf, ...) {
+  diff <- length(x) - n
+  if (diff > 0) {
+    print(head(x, n), max = n)
+    cat("... with ", format_len(diff), " more value", if (diff > 1) "s", "\n",
+        sep = "")
+  } else {
+    print(x, max = n)
+  }
+}
+
+
 print_items.tbl <- function(x, n = Inf, n_extra = 10 * n, ...) {
   print(x, n = n, n_extra = n_extra)
 }
