@@ -6,10 +6,10 @@ test_that("settings changes and views", {
 
   presets <- settings()
 
-  expect_identical(settings("control", cut = 0.25, max.print = 5),
-                   presets[c("control", "cutoff", "max.print")])
+  expect_identical(settings("control", cut = 0.25, print_max = 5),
+                   presets[c("control", "cutoff", "print_max")])
   expect_identical(settings("cutoff"), 0.25)
-  expect_identical(settings("max.print"), 5)
+  expect_identical(settings("print_max"), 5)
 
   new_value <- "BootControl"
   expect_type(settings(control = new_value), "list")
@@ -23,14 +23,14 @@ test_that("settings changes and views", {
   expect_error(settings(cutoff = character()))
 
   new_value <- "exponential"
-  expect_type(settings(dist.Surv = substr(new_value, 1, 3)), "list")
-  expect_identical(settings("dist.Surv"), new_value)
-  expect_error(settings(dist.Surv = character()))
+  expect_type(settings(distr.SurvMeans = substr(new_value, 1, 3)), "list")
+  expect_identical(settings("distr.SurvMeans"), new_value)
+  expect_error(settings(distr.SurvMeans = character()))
 
   new_value <- "exponential"
-  expect_type(settings(dist.SurvProbs = substr(new_value, 1, 3)), "list")
-  expect_identical(settings("dist.SurvProbs"), new_value)
-  expect_error(settings(dist.SurvProbs = character()))
+  expect_type(settings(distr.SurvProbs = substr(new_value, 1, 3)), "list")
+  expect_identical(settings("distr.SurvProbs"), new_value)
+  expect_error(settings(distr.SurvProbs = character()))
 
   expect_type(settings(grid = 5), "list")
   expect_s4_class(settings("grid"), "Grid")
@@ -38,13 +38,7 @@ test_that("settings changes and views", {
   expect_s4_class(settings("grid"), "Grid")
   expect_error(settings(grid = character()))
 
-  expect_type(settings(max.print = 5), "list")
-  expect_identical(settings("max.print"), 5)
-  expect_type(settings(max.print = Inf), "list")
-  expect_identical(settings("max.print"), Inf)
-  expect_error(settings(max.print = character()))
-
-  new_value <- "fleming-harrington"
+  new_value <- "breslow"
   expect_type(settings(method.EmpiricalSurv = substr(new_value, 1, 3)), "list")
   expect_identical(settings("method.EmpiricalSurv"), new_value)
   expect_error(settings(method.EmpiricalSurv = character()))
@@ -74,17 +68,29 @@ test_that("settings changes and views", {
   expect_identical(settings("metrics.Surv"), new_value)
   expect_error(settings(metrics.Surv = "mean"))
 
-  expect_type(settings(progress.resample = 0), "list")
-  expect_identical(settings("progress.resample"), FALSE)
-  expect_type(settings(progress.resample = 1), "list")
-  expect_identical(settings("progress.resample"), TRUE)
-  expect_error(settings(progress.resample = character()))
+  expect_type(settings(print_max = 5), "list")
+  expect_identical(settings("print_max"), 5)
+  expect_type(settings(print_max = Inf), "list")
+  expect_identical(settings("print_max"), Inf)
+  expect_error(settings(print_max = character()))
 
   old_values <- settings("require")
   expect_type(settings(require = c("MachineShop", "stats")), "list")
   expect_identical(settings("require"), c("stats", old_values))
   expect_error(settings(require = 1))
 
+  expect_type(settings(resample_progress = 0), "list")
+  expect_identical(settings("resample_progress"), FALSE)
+  expect_type(settings(resample_progress = 1), "list")
+  expect_identical(settings("resample_progress"), TRUE)
+  expect_error(settings(resample_progress = character()))
+
+  expect_type(settings(resample_verbose = 0), "list")
+  expect_identical(settings("resample_verbose"), FALSE)
+  expect_type(settings(resample_verbose = 1), "list")
+  expect_identical(settings("resample_verbose"), TRUE)
+  expect_error(settings(resample_verbose = character()))
+
   settings("reset")
   values <- c("cut", "grid")
   old_values <- settings(values)
@@ -104,9 +110,9 @@ test_that("settings changes and views", {
   expect_error(settings(stat.Resamples = "character"))
 
   new_value <- "median"
-  expect_type(settings(stat.train = new_value), "list")
-  expect_identical(settings("stat.train"), new_value)
-  expect_error(settings(stat.train = "character"))
+  expect_type(settings(stat.Trained = new_value), "list")
+  expect_identical(settings("stat.Trained"), new_value)
+  expect_error(settings(stat.Trained = "character"))
 
   new_value <- c("median", sd)
   expect_type(settings(stats.PartialDependence = new_value), "list")
@@ -118,12 +124,6 @@ test_that("settings changes and views", {
   expect_identical(settings("stats.Resamples"), new_value)
   expect_error(settings(stats.Resamples = "character"))
 
-  expect_type(settings(verbose.resample = 0), "list")
-  expect_identical(settings("verbose.resample"), FALSE)
-  expect_type(settings(verbose.resample = 1), "list")
-  expect_identical(settings("verbose.resample"), TRUE)
-  expect_error(settings(verbose.resample = character()))
-
   settings("reset")
   expect_identical(settings(), presets)
 })
